@@ -1,7 +1,7 @@
 #!/bin/bash
 # recognize partitioned loop devices
 
-source $TOP/tests/common
+source "$TEST_TOP/common"
 
 if ! losetup --help | grep -q 'partscan'; then
 	_not_run "losetup --partscan not available"
@@ -12,21 +12,19 @@ check_prereq mkfs.btrfs
 
 setup_root_helper
 
-run_check truncate -s0 img
-chmod a+w img
+_mktemp_local img
 cp partition-1g-1g img
 run_check truncate -s2g img
 
 loopdev=$(run_check_stdout $SUDO_HELPER losetup --partscan --find --show img)
-base=$(basename $loopdev)
+base=$(basename "$loopdev")
 
 # expect partitions named like loop0p1 etc
-for looppart in $(ls /dev/$base?*); do
-	run_check $SUDO_HELPER $TOP/mkfs.btrfs -f $looppart
-	run_check $SUDO_HELPER $TOP/btrfs inspect-internal dump-super $looppart
+for looppart in $(ls /dev/"$base"?*); do
+	run_check $SUDO_HELPER "$TOP/mkfs.btrfs" -f "$looppart"
+	run_check $SUDO_HELPER "$TOP/btrfs" inspect-internal dump-super "$looppart"
 done
 
 # cleanup
-run_check $SUDO_HELPER losetup -d $loopdev
-run_check truncate -s0 img
+run_check $SUDO_HELPER losetup -d "$loopdev"
 rm img
